Exception: DurableHuggingfaceHub::LocalEntryNotFoundError
- Inherits:
-
DurableHuggingfaceHubError
- Object
- StandardError
- DurableHuggingfaceHubError
- DurableHuggingfaceHub::LocalEntryNotFoundError
- Defined in:
- lib/durable_huggingface_hub/errors.rb
Overview
Error raised when a file is not found in the local cache.
This error occurs when local_files_only mode is enabled and the requested file is not available in the local cache.
Instance Method Summary collapse
-
#initialize(message) ⇒ LocalEntryNotFoundError
constructor
Creates a new local entry not found error.
Constructor Details
#initialize(message) ⇒ LocalEntryNotFoundError
Creates a new local entry not found error.
185 186 187 |
# File 'lib/durable_huggingface_hub/errors.rb', line 185 def initialize() super() end |