Exception: DurableHuggingfaceHub::LocalTokenNotFoundError
- Inherits:
-
DurableHuggingfaceHubError
- Object
- StandardError
- DurableHuggingfaceHubError
- DurableHuggingfaceHub::LocalTokenNotFoundError
- Defined in:
- lib/durable_huggingface_hub/errors.rb
Overview
Error raised when no local authentication token is found.
This error occurs when an operation requires authentication but no token is available in environment variables or the token file.
Instance Method Summary collapse
-
#initialize(message: nil) ⇒ LocalTokenNotFoundError
constructor
Creates a new local token not found error.
Constructor Details
#initialize(message: nil) ⇒ LocalTokenNotFoundError
Creates a new local token not found error.
259 260 261 262 263 |
# File 'lib/durable_huggingface_hub/errors.rb', line 259 def initialize(message: nil) ||= "No HuggingFace token found. " \ "Please login using DurableHuggingfaceHub.login or set the HF_TOKEN environment variable." super() end |