Exception: DurableHuggingfaceHub::RepositoryNotFoundError
- Inherits:
-
HfHubHTTPError
- Object
- StandardError
- DurableHuggingfaceHubError
- HfHubHTTPError
- DurableHuggingfaceHub::RepositoryNotFoundError
- Defined in:
- lib/durable_huggingface_hub/errors.rb
Overview
Error raised when a repository is not found on HuggingFace Hub.
This error occurs when attempting to access a repository that doesn’t exist or when the user doesn’t have permission to access it.
Instance Attribute Summary collapse
-
#repo_id ⇒ String
readonly
The repository ID that was not found.
Attributes inherited from HfHubHTTPError
#request_id, #response_body, #server_message, #status_code
Instance Method Summary collapse
-
#initialize(repo_id, message: nil) ⇒ RepositoryNotFoundError
constructor
Creates a new repository not found error.
Constructor Details
#initialize(repo_id, message: nil) ⇒ RepositoryNotFoundError
Creates a new repository not found error.
98 99 100 101 102 |
# File 'lib/durable_huggingface_hub/errors.rb', line 98 def initialize(repo_id, message: nil) @repo_id = repo_id ||= "Repository not found: #{repo_id}" super(, status_code: 404) end |
Instance Attribute Details
#repo_id ⇒ String (readonly)
Returns The repository ID that was not found.
92 93 94 |
# File 'lib/durable_huggingface_hub/errors.rb', line 92 def repo_id @repo_id end |